import { ResourceProps } from 'aws-cdk-lib';
import { Construct } from 'constructs';
/**
 * Properties of ThingWithCert construct
 */
export interface ThingWithCertProps extends ResourceProps {
    /**
     * The name of the thing
     */
    readonly thingName: string;
    /**
     * Whether to save the certificate and private key to AWS Systems Manager Parameter Store
     */
    readonly saveToParamStore?: boolean;
    /**
     * The prefix for the parameter store path
     */
    readonly paramPrefix?: string;
}
/**
 * A CDK Construct for creating an AWS IoT Core thing with a certificate
 */
export declare class ThingWithCert extends Construct {
    /**
     * The ARN of the thing
     */
    readonly thingArn: string;
    /**
     * The ID of the certificate
     */
    readonly certId: string;
    /**
     * The certificate PEM
     */
    readonly certPem: string;
    /**
     * The private key
     */
    readonly privKey: string;
    constructor(scope: Construct, id: string, props: ThingWithCertProps);
}
export declare const getParamStorePath: (thingName: string, paramPrefix?: string) => string;
