import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../IoTClient";
import { DeleteV2LoggingLevelRequest } from "../models/models_1";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DeleteV2LoggingLevelCommand}.
 */
export interface DeleteV2LoggingLevelCommandInput extends DeleteV2LoggingLevelRequest {
}
/**
 * @public
 *
 * The output of {@link DeleteV2LoggingLevelCommand}.
 */
export interface DeleteV2LoggingLevelCommandOutput extends __MetadataBearer {
}
declare const DeleteV2LoggingLevelCommand_base: {
    new (input: DeleteV2LoggingLevelCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteV2LoggingLevelCommandInput, DeleteV2LoggingLevelCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: DeleteV2LoggingLevelCommandInput): import("@smithy/smithy-client").CommandImpl<DeleteV2LoggingLevelCommandInput, DeleteV2LoggingLevelCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Deletes a logging level.</p>
 *          <p>Requires permission to access the <a href="https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions">DeleteV2LoggingLevel</a> action.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { IoTClient, DeleteV2LoggingLevelCommand } from "@aws-sdk/client-iot"; // ES Modules import
 * // const { IoTClient, DeleteV2LoggingLevelCommand } = require("@aws-sdk/client-iot"); // CommonJS import
 * const client = new IoTClient(config);
 * const input = { // DeleteV2LoggingLevelRequest
 *   targetType: "DEFAULT" || "THING_GROUP" || "CLIENT_ID" || "SOURCE_IP" || "PRINCIPAL_ID", // required
 *   targetName: "STRING_VALUE", // required
 * };
 * const command = new DeleteV2LoggingLevelCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param DeleteV2LoggingLevelCommandInput - {@link DeleteV2LoggingLevelCommandInput}
 * @returns {@link DeleteV2LoggingLevelCommandOutput}
 * @see {@link DeleteV2LoggingLevelCommandInput} for command's `input` shape.
 * @see {@link DeleteV2LoggingLevelCommandOutput} for command's `response` shape.
 * @see {@link IoTClientResolvedConfig | config} for IoTClient's `config` shape.
 *
 * @throws {@link InternalException} (server fault)
 *  <p>An unexpected error has occurred.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ServiceUnavailableException} (server fault)
 *  <p>The service is temporarily unavailable.</p>
 *
 * @throws {@link IoTServiceException}
 * <p>Base exception class for all service exceptions from IoT service.</p>
 *
 * @public
 */
export declare class DeleteV2LoggingLevelCommand extends DeleteV2LoggingLevelCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DeleteV2LoggingLevelRequest;
            output: {};
        };
        sdk: {
            input: DeleteV2LoggingLevelCommandInput;
            output: DeleteV2LoggingLevelCommandOutput;
        };
    };
}
