import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../IoTClient";
import { DescribeDomainConfigurationRequest, DescribeDomainConfigurationResponse } from "../models/models_1";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DescribeDomainConfigurationCommand}.
 */
export interface DescribeDomainConfigurationCommandInput extends DescribeDomainConfigurationRequest {
}
/**
 * @public
 *
 * The output of {@link DescribeDomainConfigurationCommand}.
 */
export interface DescribeDomainConfigurationCommandOutput extends DescribeDomainConfigurationResponse, __MetadataBearer {
}
declare const DescribeDomainConfigurationCommand_base: {
    new (input: DescribeDomainConfigurationCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeDomainConfigurationCommandInput, DescribeDomainConfigurationCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: DescribeDomainConfigurationCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeDomainConfigurationCommandInput, DescribeDomainConfigurationCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Gets summary information about a domain configuration.</p>
 *          <p>Requires permission to access the <a href="https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions">DescribeDomainConfiguration</a> action.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { IoTClient, DescribeDomainConfigurationCommand } from "@aws-sdk/client-iot"; // ES Modules import
 * // const { IoTClient, DescribeDomainConfigurationCommand } = require("@aws-sdk/client-iot"); // CommonJS import
 * const client = new IoTClient(config);
 * const input = { // DescribeDomainConfigurationRequest
 *   domainConfigurationName: "STRING_VALUE", // required
 * };
 * const command = new DescribeDomainConfigurationCommand(input);
 * const response = await client.send(command);
 * // { // DescribeDomainConfigurationResponse
 * //   domainConfigurationName: "STRING_VALUE",
 * //   domainConfigurationArn: "STRING_VALUE",
 * //   domainName: "STRING_VALUE",
 * //   serverCertificates: [ // ServerCertificates
 * //     { // ServerCertificateSummary
 * //       serverCertificateArn: "STRING_VALUE",
 * //       serverCertificateStatus: "INVALID" || "VALID",
 * //       serverCertificateStatusDetail: "STRING_VALUE",
 * //     },
 * //   ],
 * //   authorizerConfig: { // AuthorizerConfig
 * //     defaultAuthorizerName: "STRING_VALUE",
 * //     allowAuthorizerOverride: true || false,
 * //   },
 * //   domainConfigurationStatus: "ENABLED" || "DISABLED",
 * //   serviceType: "DATA" || "CREDENTIAL_PROVIDER" || "JOBS",
 * //   domainType: "ENDPOINT" || "AWS_MANAGED" || "CUSTOMER_MANAGED",
 * //   lastStatusChangeDate: new Date("TIMESTAMP"),
 * //   tlsConfig: { // TlsConfig
 * //     securityPolicy: "STRING_VALUE",
 * //   },
 * //   serverCertificateConfig: { // ServerCertificateConfig
 * //     enableOCSPCheck: true || false,
 * //   },
 * //   authenticationType: "CUSTOM_AUTH_X509" || "CUSTOM_AUTH" || "AWS_X509" || "AWS_SIGV4" || "DEFAULT",
 * //   applicationProtocol: "SECURE_MQTT" || "MQTT_WSS" || "HTTPS" || "DEFAULT",
 * //   clientCertificateConfig: { // ClientCertificateConfig
 * //     clientCertificateCallbackArn: "STRING_VALUE",
 * //   },
 * // };
 *
 * ```
 *
 * @param DescribeDomainConfigurationCommandInput - {@link DescribeDomainConfigurationCommandInput}
 * @returns {@link DescribeDomainConfigurationCommandOutput}
 * @see {@link DescribeDomainConfigurationCommandInput} for command's `input` shape.
 * @see {@link DescribeDomainConfigurationCommandOutput} for command's `response` shape.
 * @see {@link IoTClientResolvedConfig | config} for IoTClient's `config` shape.
 *
 * @throws {@link InternalFailureException} (server fault)
 *  <p>An unexpected error has occurred.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource does not exist.</p>
 *
 * @throws {@link ServiceUnavailableException} (server fault)
 *  <p>The service is temporarily unavailable.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The rate exceeds the limit.</p>
 *
 * @throws {@link UnauthorizedException} (client fault)
 *  <p>You are not authorized to perform this operation.</p>
 *
 * @throws {@link IoTServiceException}
 * <p>Base exception class for all service exceptions from IoT service.</p>
 *
 * @public
 */
export declare class DescribeDomainConfigurationCommand extends DescribeDomainConfigurationCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DescribeDomainConfigurationRequest;
            output: DescribeDomainConfigurationResponse;
        };
        sdk: {
            input: DescribeDomainConfigurationCommandInput;
            output: DescribeDomainConfigurationCommandOutput;
        };
    };
}
