import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../IoTClient";
import { DescribeRoleAliasRequest, DescribeRoleAliasResponse } from "../models/models_1";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DescribeRoleAliasCommand}.
 */
export interface DescribeRoleAliasCommandInput extends DescribeRoleAliasRequest {
}
/**
 * @public
 *
 * The output of {@link DescribeRoleAliasCommand}.
 */
export interface DescribeRoleAliasCommandOutput extends DescribeRoleAliasResponse, __MetadataBearer {
}
declare const DescribeRoleAliasCommand_base: {
    new (input: DescribeRoleAliasCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeRoleAliasCommandInput, DescribeRoleAliasCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: DescribeRoleAliasCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeRoleAliasCommandInput, DescribeRoleAliasCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Describes a role alias.</p>
 *          <p>Requires permission to access the <a href="https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions">DescribeRoleAlias</a> action.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { IoTClient, DescribeRoleAliasCommand } from "@aws-sdk/client-iot"; // ES Modules import
 * // const { IoTClient, DescribeRoleAliasCommand } = require("@aws-sdk/client-iot"); // CommonJS import
 * const client = new IoTClient(config);
 * const input = { // DescribeRoleAliasRequest
 *   roleAlias: "STRING_VALUE", // required
 * };
 * const command = new DescribeRoleAliasCommand(input);
 * const response = await client.send(command);
 * // { // DescribeRoleAliasResponse
 * //   roleAliasDescription: { // RoleAliasDescription
 * //     roleAlias: "STRING_VALUE",
 * //     roleAliasArn: "STRING_VALUE",
 * //     roleArn: "STRING_VALUE",
 * //     owner: "STRING_VALUE",
 * //     credentialDurationSeconds: Number("int"),
 * //     creationDate: new Date("TIMESTAMP"),
 * //     lastModifiedDate: new Date("TIMESTAMP"),
 * //   },
 * // };
 *
 * ```
 *
 * @param DescribeRoleAliasCommandInput - {@link DescribeRoleAliasCommandInput}
 * @returns {@link DescribeRoleAliasCommandOutput}
 * @see {@link DescribeRoleAliasCommandInput} for command's `input` shape.
 * @see {@link DescribeRoleAliasCommandOutput} for command's `response` shape.
 * @see {@link IoTClientResolvedConfig | config} for IoTClient's `config` shape.
 *
 * @throws {@link InternalFailureException} (server fault)
 *  <p>An unexpected error has occurred.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource does not exist.</p>
 *
 * @throws {@link ServiceUnavailableException} (server fault)
 *  <p>The service is temporarily unavailable.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The rate exceeds the limit.</p>
 *
 * @throws {@link UnauthorizedException} (client fault)
 *  <p>You are not authorized to perform this operation.</p>
 *
 * @throws {@link IoTServiceException}
 * <p>Base exception class for all service exceptions from IoT service.</p>
 *
 * @public
 */
export declare class DescribeRoleAliasCommand extends DescribeRoleAliasCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DescribeRoleAliasRequest;
            output: DescribeRoleAliasResponse;
        };
        sdk: {
            input: DescribeRoleAliasCommandInput;
            output: DescribeRoleAliasCommandOutput;
        };
    };
}
