import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../IoTClient";
import { DescribeThingGroupRequest, DescribeThingGroupResponse } from "../models/models_1";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link DescribeThingGroupCommand}.
 */
export interface DescribeThingGroupCommandInput extends DescribeThingGroupRequest {
}
/**
 * @public
 *
 * The output of {@link DescribeThingGroupCommand}.
 */
export interface DescribeThingGroupCommandOutput extends DescribeThingGroupResponse, __MetadataBearer {
}
declare const DescribeThingGroupCommand_base: {
    new (input: DescribeThingGroupCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeThingGroupCommandInput, DescribeThingGroupCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: DescribeThingGroupCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeThingGroupCommandInput, DescribeThingGroupCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Describe a thing group.</p>
 *          <p>Requires permission to access the <a href="https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions">DescribeThingGroup</a> action.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { IoTClient, DescribeThingGroupCommand } from "@aws-sdk/client-iot"; // ES Modules import
 * // const { IoTClient, DescribeThingGroupCommand } = require("@aws-sdk/client-iot"); // CommonJS import
 * const client = new IoTClient(config);
 * const input = { // DescribeThingGroupRequest
 *   thingGroupName: "STRING_VALUE", // required
 * };
 * const command = new DescribeThingGroupCommand(input);
 * const response = await client.send(command);
 * // { // DescribeThingGroupResponse
 * //   thingGroupName: "STRING_VALUE",
 * //   thingGroupId: "STRING_VALUE",
 * //   thingGroupArn: "STRING_VALUE",
 * //   version: Number("long"),
 * //   thingGroupProperties: { // ThingGroupProperties
 * //     thingGroupDescription: "STRING_VALUE",
 * //     attributePayload: { // AttributePayload
 * //       attributes: { // Attributes
 * //         "<keys>": "STRING_VALUE",
 * //       },
 * //       merge: true || false,
 * //     },
 * //   },
 * //   thingGroupMetadata: { // ThingGroupMetadata
 * //     parentGroupName: "STRING_VALUE",
 * //     rootToParentThingGroups: [ // ThingGroupNameAndArnList
 * //       { // GroupNameAndArn
 * //         groupName: "STRING_VALUE",
 * //         groupArn: "STRING_VALUE",
 * //       },
 * //     ],
 * //     creationDate: new Date("TIMESTAMP"),
 * //   },
 * //   indexName: "STRING_VALUE",
 * //   queryString: "STRING_VALUE",
 * //   queryVersion: "STRING_VALUE",
 * //   status: "ACTIVE" || "BUILDING" || "REBUILDING",
 * // };
 *
 * ```
 *
 * @param DescribeThingGroupCommandInput - {@link DescribeThingGroupCommandInput}
 * @returns {@link DescribeThingGroupCommandOutput}
 * @see {@link DescribeThingGroupCommandInput} for command's `input` shape.
 * @see {@link DescribeThingGroupCommandOutput} for command's `response` shape.
 * @see {@link IoTClientResolvedConfig | config} for IoTClient's `config` shape.
 *
 * @throws {@link InternalFailureException} (server fault)
 *  <p>An unexpected error has occurred.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource does not exist.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The rate exceeds the limit.</p>
 *
 * @throws {@link IoTServiceException}
 * <p>Base exception class for all service exceptions from IoT service.</p>
 *
 * @public
 */
export declare class DescribeThingGroupCommand extends DescribeThingGroupCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: DescribeThingGroupRequest;
            output: DescribeThingGroupResponse;
        };
        sdk: {
            input: DescribeThingGroupCommandInput;
            output: DescribeThingGroupCommandOutput;
        };
    };
}
