import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../IoTClient";
import { GetPackageConfigurationRequest, GetPackageConfigurationResponse } from "../models/models_1";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link GetPackageConfigurationCommand}.
 */
export interface GetPackageConfigurationCommandInput extends GetPackageConfigurationRequest {
}
/**
 * @public
 *
 * The output of {@link GetPackageConfigurationCommand}.
 */
export interface GetPackageConfigurationCommandOutput extends GetPackageConfigurationResponse, __MetadataBearer {
}
declare const GetPackageConfigurationCommand_base: {
    new (input: GetPackageConfigurationCommandInput): import("@smithy/smithy-client").CommandImpl<GetPackageConfigurationCommandInput, GetPackageConfigurationCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [GetPackageConfigurationCommandInput]): import("@smithy/smithy-client").CommandImpl<GetPackageConfigurationCommandInput, GetPackageConfigurationCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Gets information about the specified software package's configuration.</p>
 *          <p>Requires permission to access the <a href="https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions">GetPackageConfiguration</a> action.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { IoTClient, GetPackageConfigurationCommand } from "@aws-sdk/client-iot"; // ES Modules import
 * // const { IoTClient, GetPackageConfigurationCommand } = require("@aws-sdk/client-iot"); // CommonJS import
 * const client = new IoTClient(config);
 * const input = {};
 * const command = new GetPackageConfigurationCommand(input);
 * const response = await client.send(command);
 * // { // GetPackageConfigurationResponse
 * //   versionUpdateByJobsConfig: { // VersionUpdateByJobsConfig
 * //     enabled: true || false,
 * //     roleArn: "STRING_VALUE",
 * //   },
 * // };
 *
 * ```
 *
 * @param GetPackageConfigurationCommandInput - {@link GetPackageConfigurationCommandInput}
 * @returns {@link GetPackageConfigurationCommandOutput}
 * @see {@link GetPackageConfigurationCommandInput} for command's `input` shape.
 * @see {@link GetPackageConfigurationCommandOutput} for command's `response` shape.
 * @see {@link IoTClientResolvedConfig | config} for IoTClient's `config` shape.
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>Internal error from the service that indicates an unexpected error or that the service
 *             is unavailable.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The rate exceeds the limit.</p>
 *
 * @throws {@link IoTServiceException}
 * <p>Base exception class for all service exceptions from IoT service.</p>
 *
 * @public
 */
export declare class GetPackageConfigurationCommand extends GetPackageConfigurationCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: {};
            output: GetPackageConfigurationResponse;
        };
        sdk: {
            input: GetPackageConfigurationCommandInput;
            output: GetPackageConfigurationCommandOutput;
        };
    };
}
