import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../IoTClient";
import { ListCustomMetricsRequest, ListCustomMetricsResponse } from "../models/models_1";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListCustomMetricsCommand}.
 */
export interface ListCustomMetricsCommandInput extends ListCustomMetricsRequest {
}
/**
 * @public
 *
 * The output of {@link ListCustomMetricsCommand}.
 */
export interface ListCustomMetricsCommandOutput extends ListCustomMetricsResponse, __MetadataBearer {
}
declare const ListCustomMetricsCommand_base: {
    new (input: ListCustomMetricsCommandInput): import("@smithy/smithy-client").CommandImpl<ListCustomMetricsCommandInput, ListCustomMetricsCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [ListCustomMetricsCommandInput]): import("@smithy/smithy-client").CommandImpl<ListCustomMetricsCommandInput, ListCustomMetricsCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>
 *       Lists your Device Defender detect custom metrics.
 *     </p>
 *          <p>Requires permission to access the <a href="https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions">ListCustomMetrics</a> action.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { IoTClient, ListCustomMetricsCommand } from "@aws-sdk/client-iot"; // ES Modules import
 * // const { IoTClient, ListCustomMetricsCommand } = require("@aws-sdk/client-iot"); // CommonJS import
 * const client = new IoTClient(config);
 * const input = { // ListCustomMetricsRequest
 *   nextToken: "STRING_VALUE",
 *   maxResults: Number("int"),
 * };
 * const command = new ListCustomMetricsCommand(input);
 * const response = await client.send(command);
 * // { // ListCustomMetricsResponse
 * //   metricNames: [ // MetricNames
 * //     "STRING_VALUE",
 * //   ],
 * //   nextToken: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param ListCustomMetricsCommandInput - {@link ListCustomMetricsCommandInput}
 * @returns {@link ListCustomMetricsCommandOutput}
 * @see {@link ListCustomMetricsCommandInput} for command's `input` shape.
 * @see {@link ListCustomMetricsCommandOutput} for command's `response` shape.
 * @see {@link IoTClientResolvedConfig | config} for IoTClient's `config` shape.
 *
 * @throws {@link InternalFailureException} (server fault)
 *  <p>An unexpected error has occurred.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The rate exceeds the limit.</p>
 *
 * @throws {@link IoTServiceException}
 * <p>Base exception class for all service exceptions from IoT service.</p>
 *
 * @public
 */
export declare class ListCustomMetricsCommand extends ListCustomMetricsCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListCustomMetricsRequest;
            output: ListCustomMetricsResponse;
        };
        sdk: {
            input: ListCustomMetricsCommandInput;
            output: ListCustomMetricsCommandOutput;
        };
    };
}
