import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../IoTClient";
import { ListManagedJobTemplatesRequest } from "../models/models_1";
import { ListManagedJobTemplatesResponse } from "../models/models_2";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListManagedJobTemplatesCommand}.
 */
export interface ListManagedJobTemplatesCommandInput extends ListManagedJobTemplatesRequest {
}
/**
 * @public
 *
 * The output of {@link ListManagedJobTemplatesCommand}.
 */
export interface ListManagedJobTemplatesCommandOutput extends ListManagedJobTemplatesResponse, __MetadataBearer {
}
declare const ListManagedJobTemplatesCommand_base: {
    new (input: ListManagedJobTemplatesCommandInput): import("@smithy/smithy-client").CommandImpl<ListManagedJobTemplatesCommandInput, ListManagedJobTemplatesCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [ListManagedJobTemplatesCommandInput]): import("@smithy/smithy-client").CommandImpl<ListManagedJobTemplatesCommandInput, ListManagedJobTemplatesCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Returns a list of managed job templates.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { IoTClient, ListManagedJobTemplatesCommand } from "@aws-sdk/client-iot"; // ES Modules import
 * // const { IoTClient, ListManagedJobTemplatesCommand } = require("@aws-sdk/client-iot"); // CommonJS import
 * const client = new IoTClient(config);
 * const input = { // ListManagedJobTemplatesRequest
 *   templateName: "STRING_VALUE",
 *   maxResults: Number("int"),
 *   nextToken: "STRING_VALUE",
 * };
 * const command = new ListManagedJobTemplatesCommand(input);
 * const response = await client.send(command);
 * // { // ListManagedJobTemplatesResponse
 * //   managedJobTemplates: [ // ManagedJobTemplatesSummaryList
 * //     { // ManagedJobTemplateSummary
 * //       templateArn: "STRING_VALUE",
 * //       templateName: "STRING_VALUE",
 * //       description: "STRING_VALUE",
 * //       environments: [ // Environments
 * //         "STRING_VALUE",
 * //       ],
 * //       templateVersion: "STRING_VALUE",
 * //     },
 * //   ],
 * //   nextToken: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param ListManagedJobTemplatesCommandInput - {@link ListManagedJobTemplatesCommandInput}
 * @returns {@link ListManagedJobTemplatesCommandOutput}
 * @see {@link ListManagedJobTemplatesCommandInput} for command's `input` shape.
 * @see {@link ListManagedJobTemplatesCommandOutput} for command's `response` shape.
 * @see {@link IoTClientResolvedConfig | config} for IoTClient's `config` shape.
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>Internal error from the service that indicates an unexpected error or that the service
 *             is unavailable.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource does not exist.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The rate exceeds the limit.</p>
 *
 * @throws {@link IoTServiceException}
 * <p>Base exception class for all service exceptions from IoT service.</p>
 *
 * @public
 */
export declare class ListManagedJobTemplatesCommand extends ListManagedJobTemplatesCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListManagedJobTemplatesRequest;
            output: ListManagedJobTemplatesResponse;
        };
        sdk: {
            input: ListManagedJobTemplatesCommandInput;
            output: ListManagedJobTemplatesCommandOutput;
        };
    };
}
