import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../IoTClient";
import { SetV2LoggingLevelRequest } from "../models/models_2";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link SetV2LoggingLevelCommand}.
 */
export interface SetV2LoggingLevelCommandInput extends SetV2LoggingLevelRequest {
}
/**
 * @public
 *
 * The output of {@link SetV2LoggingLevelCommand}.
 */
export interface SetV2LoggingLevelCommandOutput extends __MetadataBearer {
}
declare const SetV2LoggingLevelCommand_base: {
    new (input: SetV2LoggingLevelCommandInput): import("@smithy/smithy-client").CommandImpl<SetV2LoggingLevelCommandInput, SetV2LoggingLevelCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: SetV2LoggingLevelCommandInput): import("@smithy/smithy-client").CommandImpl<SetV2LoggingLevelCommandInput, SetV2LoggingLevelCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Sets the logging level.</p>
 *          <p>Requires permission to access the <a href="https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions">SetV2LoggingLevel</a> action.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { IoTClient, SetV2LoggingLevelCommand } from "@aws-sdk/client-iot"; // ES Modules import
 * // const { IoTClient, SetV2LoggingLevelCommand } = require("@aws-sdk/client-iot"); // CommonJS import
 * const client = new IoTClient(config);
 * const input = { // SetV2LoggingLevelRequest
 *   logTarget: { // LogTarget
 *     targetType: "DEFAULT" || "THING_GROUP" || "CLIENT_ID" || "SOURCE_IP" || "PRINCIPAL_ID", // required
 *     targetName: "STRING_VALUE",
 *   },
 *   logLevel: "DEBUG" || "INFO" || "ERROR" || "WARN" || "DISABLED", // required
 * };
 * const command = new SetV2LoggingLevelCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param SetV2LoggingLevelCommandInput - {@link SetV2LoggingLevelCommandInput}
 * @returns {@link SetV2LoggingLevelCommandOutput}
 * @see {@link SetV2LoggingLevelCommandInput} for command's `input` shape.
 * @see {@link SetV2LoggingLevelCommandOutput} for command's `response` shape.
 * @see {@link IoTClientResolvedConfig | config} for IoTClient's `config` shape.
 *
 * @throws {@link InternalException} (server fault)
 *  <p>An unexpected error has occurred.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link LimitExceededException} (client fault)
 *  <p>A limit has been exceeded.</p>
 *
 * @throws {@link NotConfiguredException} (client fault)
 *  <p>The resource is not configured.</p>
 *
 * @throws {@link ServiceUnavailableException} (server fault)
 *  <p>The service is temporarily unavailable.</p>
 *
 * @throws {@link IoTServiceException}
 * <p>Base exception class for all service exceptions from IoT service.</p>
 *
 * @public
 */
export declare class SetV2LoggingLevelCommand extends SetV2LoggingLevelCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: SetV2LoggingLevelRequest;
            output: {};
        };
        sdk: {
            input: SetV2LoggingLevelCommandInput;
            output: SetV2LoggingLevelCommandOutput;
        };
    };
}
