import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../IoTClient";
import { StartThingRegistrationTaskRequest, StartThingRegistrationTaskResponse } from "../models/models_2";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link StartThingRegistrationTaskCommand}.
 */
export interface StartThingRegistrationTaskCommandInput extends StartThingRegistrationTaskRequest {
}
/**
 * @public
 *
 * The output of {@link StartThingRegistrationTaskCommand}.
 */
export interface StartThingRegistrationTaskCommandOutput extends StartThingRegistrationTaskResponse, __MetadataBearer {
}
declare const StartThingRegistrationTaskCommand_base: {
    new (input: StartThingRegistrationTaskCommandInput): import("@smithy/smithy-client").CommandImpl<StartThingRegistrationTaskCommandInput, StartThingRegistrationTaskCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: StartThingRegistrationTaskCommandInput): import("@smithy/smithy-client").CommandImpl<StartThingRegistrationTaskCommandInput, StartThingRegistrationTaskCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Creates a bulk thing provisioning task.</p>
 *          <p>Requires permission to access the <a href="https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions">StartThingRegistrationTask</a> action.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { IoTClient, StartThingRegistrationTaskCommand } from "@aws-sdk/client-iot"; // ES Modules import
 * // const { IoTClient, StartThingRegistrationTaskCommand } = require("@aws-sdk/client-iot"); // CommonJS import
 * const client = new IoTClient(config);
 * const input = { // StartThingRegistrationTaskRequest
 *   templateBody: "STRING_VALUE", // required
 *   inputFileBucket: "STRING_VALUE", // required
 *   inputFileKey: "STRING_VALUE", // required
 *   roleArn: "STRING_VALUE", // required
 * };
 * const command = new StartThingRegistrationTaskCommand(input);
 * const response = await client.send(command);
 * // { // StartThingRegistrationTaskResponse
 * //   taskId: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param StartThingRegistrationTaskCommandInput - {@link StartThingRegistrationTaskCommandInput}
 * @returns {@link StartThingRegistrationTaskCommandOutput}
 * @see {@link StartThingRegistrationTaskCommandInput} for command's `input` shape.
 * @see {@link StartThingRegistrationTaskCommandOutput} for command's `response` shape.
 * @see {@link IoTClientResolvedConfig | config} for IoTClient's `config` shape.
 *
 * @throws {@link InternalFailureException} (server fault)
 *  <p>An unexpected error has occurred.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The rate exceeds the limit.</p>
 *
 * @throws {@link UnauthorizedException} (client fault)
 *  <p>You are not authorized to perform this operation.</p>
 *
 * @throws {@link IoTServiceException}
 * <p>Base exception class for all service exceptions from IoT service.</p>
 *
 * @public
 */
export declare class StartThingRegistrationTaskCommand extends StartThingRegistrationTaskCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: StartThingRegistrationTaskRequest;
            output: StartThingRegistrationTaskResponse;
        };
        sdk: {
            input: StartThingRegistrationTaskCommandInput;
            output: StartThingRegistrationTaskCommandOutput;
        };
    };
}
