import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../IoTClient";
import { UpdateAccountAuditConfigurationRequest, UpdateAccountAuditConfigurationResponse } from "../models/models_2";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link UpdateAccountAuditConfigurationCommand}.
 */
export interface UpdateAccountAuditConfigurationCommandInput extends UpdateAccountAuditConfigurationRequest {
}
/**
 * @public
 *
 * The output of {@link UpdateAccountAuditConfigurationCommand}.
 */
export interface UpdateAccountAuditConfigurationCommandOutput extends UpdateAccountAuditConfigurationResponse, __MetadataBearer {
}
declare const UpdateAccountAuditConfigurationCommand_base: {
    new (input: UpdateAccountAuditConfigurationCommandInput): import("@smithy/smithy-client").CommandImpl<UpdateAccountAuditConfigurationCommandInput, UpdateAccountAuditConfigurationCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [UpdateAccountAuditConfigurationCommandInput]): import("@smithy/smithy-client").CommandImpl<UpdateAccountAuditConfigurationCommandInput, UpdateAccountAuditConfigurationCommandOutput, IoTClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Configures or reconfigures the Device Defender audit settings for this account.
 *           Settings include how audit notifications are sent and which audit checks are
 *           enabled or disabled.</p>
 *          <p>Requires permission to access the <a href="https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsiot.html#awsiot-actions-as-permissions">UpdateAccountAuditConfiguration</a> action.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { IoTClient, UpdateAccountAuditConfigurationCommand } from "@aws-sdk/client-iot"; // ES Modules import
 * // const { IoTClient, UpdateAccountAuditConfigurationCommand } = require("@aws-sdk/client-iot"); // CommonJS import
 * const client = new IoTClient(config);
 * const input = { // UpdateAccountAuditConfigurationRequest
 *   roleArn: "STRING_VALUE",
 *   auditNotificationTargetConfigurations: { // AuditNotificationTargetConfigurations
 *     "<keys>": { // AuditNotificationTarget
 *       targetArn: "STRING_VALUE",
 *       roleArn: "STRING_VALUE",
 *       enabled: true || false,
 *     },
 *   },
 *   auditCheckConfigurations: { // AuditCheckConfigurations
 *     "<keys>": { // AuditCheckConfiguration
 *       enabled: true || false,
 *     },
 *   },
 * };
 * const command = new UpdateAccountAuditConfigurationCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param UpdateAccountAuditConfigurationCommandInput - {@link UpdateAccountAuditConfigurationCommandInput}
 * @returns {@link UpdateAccountAuditConfigurationCommandOutput}
 * @see {@link UpdateAccountAuditConfigurationCommandInput} for command's `input` shape.
 * @see {@link UpdateAccountAuditConfigurationCommandOutput} for command's `response` shape.
 * @see {@link IoTClientResolvedConfig | config} for IoTClient's `config` shape.
 *
 * @throws {@link InternalFailureException} (server fault)
 *  <p>An unexpected error has occurred.</p>
 *
 * @throws {@link InvalidRequestException} (client fault)
 *  <p>The request is not valid.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>The rate exceeds the limit.</p>
 *
 * @throws {@link IoTServiceException}
 * <p>Base exception class for all service exceptions from IoT service.</p>
 *
 * @public
 */
export declare class UpdateAccountAuditConfigurationCommand extends UpdateAccountAuditConfigurationCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: UpdateAccountAuditConfigurationRequest;
            output: {};
        };
        sdk: {
            input: UpdateAccountAuditConfigurationCommandInput;
            output: UpdateAccountAuditConfigurationCommandOutput;
        };
    };
}
